# sad_cin/__init__.py

"""
Pacote sad_cin: Métodos de apoio à decisão  multi critério

Uso:
  from sad_cin import decision_support

Versão:
  0.4.0
"""

__version__ = "0.4.0"

from .main import decision_support

__all__ = [ "decision_support" ]
